@@ -144,38 +144,48 @@ class Postgres_Handler:
         
         
     #This needs to be looked at, likely there are only certain fields that will be passed and the rest will be created either in lambda or S3/postgresql
-    def insert_row(self, kwargs):
+    def insert_row(self, **kwargs):
         
         #Values dictioniary for sql parameters
-        values_dict = {}
+        # values_dict = {}
         
-        #Empty strings for column names and column values to be added
-        column_names_string = ''
-        column_values_string = ''
+        # #Empty strings for column names and column values to be added
+        # column_names_string = ''
+        # column_values_string = ''
         
         #checks for the table name in args
         if self.table_name_key not in kwargs:
             assert("Error: table_name required as argument")
-        table_name = kwargs[self.table_name_key]
+        # table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
-        query_start = f'INSERT INTO {{self.table_name_key}}'
-        values_dict[self.table_name_key] = sql.Identifier(table_name)
+        query = sql.sql(
+            'INSERT INTO {table_name} ({columns}) VALUES({values})'.format(
+                columns = sql.SQL(', ').join(
+                    map(sql.Identifier, kwargs.keys())
+                ),
+                values = sql.SQL(', ').join(
+                    map(sql.Placeholder, kwargs.keys())
+                ),
+                table_name = kwargs[self.table_name_key]
+            )
+        )
+    
         
         #Iterates through the arguments adds the key to the column_name, and the value to the column_value
-        for key, value in kwargs.items():
-            column_names_string += f'"{key}",'
-            column_values_string += f"%({key})s,"
-            values_dict[key] = value
+        # for key, value in kwargs.items():
+        #     column_names_string += f'"{key}",'
+        #     column_values_string += f"%({key})s,"
+        #     values_dict[key] = value
             
-        column_names = column_names_string[:-1]
-        column_values = column_values_string[:-1]
-        
-        #Builds the final SQL query for updating values
-        query = f'{query_start}({column_names}) VALUES({column_values})'
+        # column_names = column_names_string[:-1]
+        # column_values = column_values_string[:-1]
         
+        # #Builds the final SQL query for updating values
+        # query = f'{query_start}({column_names}) VALUES({column_values})'
+        # query = query.format(table_name = sql.Identifier(table_name))
         #Runs the command
-        results = self.__run_query(query, values_dict)
+        results = self.__run_query(query, kwargs)
         return self.__format_results(results)
         
     def __format_results(self, results):
